#
# spec file for package hawtjni-maven-plugin
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           hawtjni-maven-plugin
Version:        1.18
Release:        2.2
Summary:        Use HawtJNI from a maven plugin
License:        Apache-2.0 AND EPL-1.0 AND BSD-3-Clause
URL:            https://github.com/fusesource/hawtjni
Source0:        https://github.com/fusesource/hawtjni/archive/hawtjni-project-%{version}.tar.gz
Patch0:         use-commons-lang3.patch
BuildRequires:  fdupes
BuildRequires:  maven-local
BuildRequires:  mvn(org.apache.maven.plugin-tools:maven-plugin-annotations)
BuildRequires:  mvn(org.apache.maven.plugins:maven-plugin-plugin)
BuildRequires:  mvn(org.apache.maven:maven-archiver)
BuildRequires:  mvn(org.apache.maven:maven-artifact)
BuildRequires:  mvn(org.apache.maven:maven-compat)
BuildRequires:  mvn(org.apache.maven:maven-core)
BuildRequires:  mvn(org.apache.maven:maven-plugin-api)
BuildRequires:  mvn(org.codehaus.plexus:plexus-archiver)
BuildRequires:  mvn(org.codehaus.plexus:plexus-interpolation)
BuildRequires:  mvn(org.codehaus.plexus:plexus-io)
BuildRequires:  mvn(org.codehaus.plexus:plexus-utils)
BuildRequires:  mvn(org.fusesource.hawtjni:hawtjni-generator) >= %{version}
BuildRequires:  mvn(org.fusesource:fusesource-pom:pom:)
Requires:       autoconf
Requires:       automake
Requires:       gcc
Requires:       libtool
Requires:       make
BuildArch:      noarch

%description
HawtJNI is a code generator that produces the JNI code needed to
implement java native methods. It is based on the jnigen code generator
that is part of the SWT Tools project which is used to generate all the
JNI code which powers the eclipse platform.

This package allows to use HawtJNI from a maven plugin.

%package javadoc
Summary:        Javadocs for %{name}

%description javadoc
This package contains the API documentation for %{name}.

%prep
%setup -q -n hawtjni-hawtjni-project-%{version}
%patch -P 0 -p1

# We build only the maven plugin in this one
%pom_disable_module hawtjni-example
%pom_disable_module hawtjni-generator
%pom_disable_module hawtjni-runtime

%pom_remove_plugin -r :maven-eclipse-plugin

%pom_change_dep :maven-artifact-manager :maven-core:\${mavenVersion} hawtjni-maven-plugin
%pom_change_dep :maven-project :maven-compat:\${mavenVersion} hawtjni-maven-plugin

%{mvn_package} :hawtjni-project __noinstall

%{mvn_alias} :hawtjni-maven-plugin :maven-hawtjni-plugin

%build
%{mvn_build} -f -- \
%if %{?pkg_vcmp:%pkg_vcmp java-devel >= 9}%{!?pkg_vcmp:0}
    -Dmaven.compiler.release=8 \
%endif
    -Dsource=8

%install
%mvn_install
%fdupes -s %{buildroot}%{_javadocdir}

%files -f .mfiles
%license license.txt
%doc readme.md changelog.md

%files javadoc -f .mfiles-javadoc
%license license.txt

%changelog
* Thu Oct 31 2024 Fridrich Strba <fstrba@suse.com>
- Port to use Maven 3.x APIs instead of the old Maven 2.2.1
- Make the hawtjni-maven-plugin require autotools, make and gcc
  * it uses them for building
- Sanitize the dependency list so that it corresponds to the
  reality
* Wed Oct  9 2024 Fridrich Strba <fstrba@suse.com>
- Add _multibuild to define 2nd spec file as additional flavor.
* Mon Mar 28 2022 Fridrich Strba <fstrba@suse.com>
- Upgrade to version 1.18
- Added patch:
  * use-commons-lang3.patch
    + use commons-lang3 instead of the old commons-lang
* Wed Mar 23 2022 Fridrich Strba <fstrba@suse.com>
- Build with java source and target levels 8
* Thu Mar  3 2022 Fridrich Strba <fstrba@suse.com>
- Use in the path of hawtjni-generator the asm-all.jar that is not
  modular. This solves some problems with ASM version mismatch.
* Mon Nov 25 2019 Fridrich Strba <fstrba@suse.com>
- Upgrade to upsteam version 1.17
- Add dependency on mvn(commons-lang:commons-lang) that is missing
- Add dependency on mvn(org.apache.maven:maven-compat) that is
  missing
* Sun Nov 24 2019 Fridrich Strba <fstrba@suse.com>
- Specify maven.compiler.release to fix build with jdk9+ and newer
  maven-javadoc-plugin
* Wed Oct  2 2019 Fridrich Strba <fstrba@suse.com>
- Correct the URL that does not exist anymore
- Clean the spec file with spec-cleaner
* Wed Oct  2 2019 Fridrich Strba <fstrba@suse.com>
- Initial packaging of hawtjni-maven-plugin 1.16 as a separate
  package with its own spec file
* Mon Sep 30 2019 Fridrich Strba <fstrba@suse.com>
- Remove references to the parent pom from all artifacts and
  don't distribute any parent artifact, since we don't build
  this with maven, so the parent artifacts are pointless
* Tue Apr  9 2019 Fridrich Strba <fstrba@suse.com>
- Remove reference to the parent pom since we are not building
  using Maven.
* Wed Jan 23 2019 Fridrich Strba <fstrba@suse.com>
- Initial package for hawtjni version 1.16
